#ifndef TABLES_H
#define TABLES_H

#include "types.h"

extern const int shine_slen1_tab[16];
extern const int shine_slen2_tab[16];

extern const int samplerates[9];
extern const int bitrates[16][4];

extern const int  shine_scale_fact_band_index[9][23];
extern const int32_t shine_enwindow[];

#endif

